@@ -17,6 +17,7 @@
 #include <KDesktopFile>
 #include <KJobUiDelegate>
 #include <KService>
+#include <KSycoca>
 
 #ifdef Q_OS_UNIX
 #include <signal.h> // kill
@@ -32,6 +33,7 @@ QTEST_GUILESS_MAIN(ApplicationLauncherJobTest)
 void ApplicationLauncherJobTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
+    KSycoca::setupTestMenu();
     m_tempService = createTempService();
 }
 
@@ -160,6 +162,8 @@ void ApplicationLauncherJobTest::shouldFailOnNonExecutableDesktopFile()
     writeTempServiceDesktopFile(desktopFilePath);
     m_filesToRemove.append(desktopFilePath);
 
+    QTest::ignoreMessage(QtInfoMsg, QRegularExpression("Access to \".*\" denied, not owned by root and executable flag not set."));
+
     const QString srcFile = srcDir + "/srcfile";
     createSrcFile(srcFile);
     const QList<QUrl> urls{QUrl::fromLocalFile(srcFile)};
@@ -222,7 +226,7 @@ void ApplicationLauncherJobTest::shouldFailOnNonExistingExecutable()
     QFETCH(bool, fullPath);
 
     const QString desktopFilePath =
-        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices6/non_existing_executable.desktop");
+        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/applications/non_existing_executable.desktop");
     KDesktopFile file(desktopFilePath);
     KConfigGroup group = file.desktopGroup();
     group.writeEntry("Name", "KRunUnittestService");
@@ -254,7 +258,7 @@ void ApplicationLauncherJobTest::shouldFailOnNonExistingExecutable()
 void ApplicationLauncherJobTest::shouldFailOnInvalidService()
 {
     const QString desktopFilePath =
-        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices6/invalid_service.desktop");
+        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/applications/invalid_service.desktop");
     KDesktopFile file(desktopFilePath);
     KConfigGroup group = file.desktopGroup();
     group.writeEntry("Name", "KRunUnittestService");
@@ -277,7 +281,7 @@ void ApplicationLauncherJobTest::shouldFailOnInvalidService()
 void ApplicationLauncherJobTest::shouldFailOnServiceWithNoExec()
 {
     const QString desktopFilePath =
-        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices6/invalid_service.desktop");
+        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/applications/invalid_service.desktop");
     KDesktopFile file(desktopFilePath);
     KConfigGroup group = file.desktopGroup();
     group.writeEntry("Name", "KRunUnittestServiceNoExec");
@@ -309,7 +313,7 @@ void ApplicationLauncherJobTest::shouldFailOnExecutableWithoutPermissions()
     // Note that it's missing executable permissions
 
     const QString desktopFilePath =
-        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices6/invalid_service.desktop");
+        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/applications/invalid_service.desktop");
     KDesktopFile file(desktopFilePath);
     KConfigGroup group = file.desktopGroup();
     group.writeEntry("Name", "KRunUnittestServiceNoPermission");
@@ -425,7 +429,7 @@ void ApplicationLauncherJobTest::writeTempServiceDesktopFile(const QString &file
 QString ApplicationLauncherJobTest::createTempService()
 {
     const QString fileName = s_tempServiceName;
-    const QString fakeService = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices6/") + fileName;
+    const QString fakeService = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/applications/") + fileName;
     writeTempServiceDesktopFile(fakeService);
     m_filesToRemove.append(fakeService);
     return fakeService;
