@@ -5,24 +5,23 @@
     SPDX-License-Identifier: GPL-2.0-only
 */
 
-#include <QObject>
 #include <QDBusInterface>
-#include <QTemporaryDir>
-#include <QSignalSpy>
-
-#include <KBookmarkManager>
-#include <KBookmark>
 #include <QDebug>
-#include <kfileplacesmodel.h>
-#include <solid/device.h>
+#include <QObject>
+#include <QSignalSpy>
+#include <QTemporaryDir>
+#include <QTest>
+
+#include <KBookmark>
+#include <KBookmarkManager>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KProtocolInfo>
-
-#include <QTest>
+#include <QStandardPaths>
+#include <kfileplacesmodel.h>
+#include <solid/device.h>
 
 #include <stdlib.h>
-#include <QStandardPaths>
 
 Q_DECLARE_METATYPE(KFilePlacesModel::GroupType)
 
@@ -72,7 +71,6 @@ private Q_SLOTS:
     void testPlaceGroupHiddenGroupIndexesIntegrity();
     void testPlaceGroupHiddenSignal();
     void testPlaceGroupHiddenRole();
-    void testFilterWithAlternativeApplicationName();
     void testSupportedSchemes();
 
 private:
@@ -100,7 +98,6 @@ void KFilePlacesModelTest::initTestCase()
 {
     QVERIFY(m_tmpHome.isValid());
     qputenv("HOME", m_tmpHome.path().toUtf8()); // use a empty home dir
-    qputenv("KDE_FORK_SLAVES", "yes"); // to avoid a runtime dependency on klauncher
 
     QStandardPaths::setTestModeEnabled(true);
 
@@ -109,7 +106,7 @@ void KFilePlacesModelTest::initTestCase()
 
     // disable baloo by default
     KConfig config(QStringLiteral("baloofilerc"));
-    KConfigGroup basicSettings = config.group("Basic Settings");
+    KConfigGroup basicSettings = config.group(QStringLiteral("Basic Settings"));
     basicSettings.writeEntry("Indexing-Enabled", false);
     config.sync();
 
@@ -126,13 +123,13 @@ void KFilePlacesModelTest::initTestCase()
 
 void KFilePlacesModelTest::createPlacesModels()
 {
-    KBookmarkManager *mgr = KBookmarkManager::managerForExternalFile(bookmarksFile());
-    QSignalSpy spy(mgr, &KBookmarkManager::changed);
+    KBookmarkManager mgr(bookmarksFile());
+    QSignalSpy spy(&mgr, &KBookmarkManager::changed);
     m_places = new KFilePlacesModel();
     m_places2 = new KFilePlacesModel();
 
     // When the xbel file is empty, KFilePlacesModel fills it with 3 default items
-    // 5 when ioslave recentlyused:/ is installed
+    // 5 when KIO worker recentlyused:/ is installed
     QCOMPARE(m_places->rowCount(), m_hasRecentlyUsedKio ? 5 : 3);
 
     QVERIFY(spy.wait());
@@ -161,30 +158,30 @@ QStringList KFilePlacesModelTest::placesUrls(KFilePlacesModel *model) const
         urls << currentModel->url(index).toDisplayString(QUrl::PreferLocalFile);
     }
     return urls;
- }
+}
 
-#define CHECK_PLACES_URLS(urls)                                              \
-    if (placesUrls() != urls) {                                              \
-        qDebug() << "Expected:" << urls;                                     \
-        qDebug() << "Got:" << placesUrls();                                  \
-        QCOMPARE(placesUrls(), urls);                                        \
-    }                                                                        \
-    for (int row = 0; row < urls.size(); ++row) {                            \
-        QModelIndex index = m_places->index(row, 0);                         \
+/* clang-format off */
+#define CHECK_PLACES_URLS(urls) \
+    if (placesUrls() != urls) { \
+        qDebug() << "Expected:" << urls; \
+        qDebug() << "Got:" << placesUrls(); \
+        QCOMPARE(placesUrls(), urls); \
+    } \
+    for (int row = 0; row < urls.size(); ++row) { \
+        QModelIndex index = m_places->index(row, 0); \
         \
         QCOMPARE(m_places->url(index).toString(), QUrl::fromUserInput(urls[row]).toString()); \
-        QCOMPARE(m_places->data(index, KFilePlacesModel::UrlRole).toUrl(),   \
-                 QUrl(m_places->url(index)));                                \
+        QCOMPARE(m_places->data(index, KFilePlacesModel::UrlRole).toUrl(), QUrl(m_places->url(index))); \
         \
-        index = m_places2->index(row, 0);                                    \
+        index = m_places2->index(row, 0);                                                               \
         \
         QCOMPARE(m_places2->url(index).toString(), QUrl::fromUserInput(urls[row]).toString()); \
-        QCOMPARE(m_places2->data(index, KFilePlacesModel::UrlRole).toUrl(),  \
-                 QUrl(m_places2->url(index)));                               \
-    }                                                                        \
+        QCOMPARE(m_places2->data(index, KFilePlacesModel::UrlRole).toUrl(), QUrl(m_places2->url(index))); \
+    } \
     \
-    QCOMPARE(urls.size(), m_places->rowCount());                             \
+    QCOMPARE(urls.size(), m_places->rowCount()); \
     QCOMPARE(urls.size(), m_places2->rowCount());
+/*clang-format on */
 
 QDBusInterface *KFilePlacesModelTest::fakeManager()
 {
@@ -236,10 +233,7 @@ static const QStringList initialListOfRemovableDevices()
 
 static const QStringList initialListOfUrls()
 {
-    return QStringList() << initialListOfPlaces()
-                         << initialListOfShared()
-                         << initialListOfRecent()
-                         << initialListOfDevices()
+    return QStringList() << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices()
                          << initialListOfRemovableDevices();
 }
 
@@ -256,30 +250,30 @@ void KFilePlacesModelTest::testAddingInLaterVersion_data()
 
     // Create a places file with only Home in it, and no version number
     static const char contentsPart1[] =
-            "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-            "<xbel xmlns:bookmark=\"http://www.freedesktop.org/standards/desktop-bookmarks\">\n";
+        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+        "<xbel xmlns:bookmark=\"http://www.freedesktop.org/standards/desktop-bookmarks\">\n";
 
     static const char versionXml[] =
-            "  <info>\n"
-            "   <metadata owner=\"http://www.kde.org\">\n"
-            "    <kde_places_version>2</kde_places_version>\n"
-            "   </metadata>\n"
-            "  </info>\n";
+        "  <info>\n"
+        "   <metadata owner=\"http://www.kde.org\">\n"
+        "    <kde_places_version>2</kde_places_version>\n"
+        "   </metadata>\n"
+        "  </info>\n";
 
     static const char contentsPart2[] =
-            " <bookmark href=\"trash:/\">\n"
-            "  <title>Home</title>\n"
-            "  <info>\n"
-            "   <metadata owner=\"http://freedesktop.org\">\n"
-            "    <bookmark:icon name=\"user-home\"/>\n"
-            "   </metadata>\n"
-            "   <metadata owner=\"http://www.kde.org\">\n"
-            "    <ID>1481703882/0</ID>\n"
-            "    <isSystemItem>true</isSystemItem>\n"
-            "   </metadata>\n"
-            "  </info>\n"
-            " </bookmark>\n"
-            "</xbel>";
+        " <bookmark href=\"trash:/\">\n"
+        "  <title>Home</title>\n"
+        "  <info>\n"
+        "   <metadata owner=\"http://freedesktop.org\">\n"
+        "    <bookmark:icon name=\"user-home\"/>\n"
+        "   </metadata>\n"
+        "   <metadata owner=\"http://www.kde.org\">\n"
+        "    <ID>1481703882/0</ID>\n"
+        "    <isSystemItem>true</isSystemItem>\n"
+        "   </metadata>\n"
+        "  </info>\n"
+        " </bookmark>\n"
+        "</xbel>";
 
     // No version key: KFilePlacesModel will add the missing entries: home and remote
     // Just not in the usual order
@@ -288,14 +282,10 @@ void KFilePlacesModelTest::testAddingInLaterVersion_data()
     QTest::newRow("just_home_no_version") << (QByteArray(contentsPart1) + contentsPart2) << expectedWithReorder;
 
     // Existing version key: home and remote were removed by the user, leave them out
-    QStringList expectedUrls{ QStringLiteral("trash:/") };
-    expectedUrls << initialListOfShared()
-                 << initialListOfRecent()
-                 << initialListOfDevices()
-                 << initialListOfRemovableDevices();
+    QStringList expectedUrls{QStringLiteral("trash:/")};
+    expectedUrls << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     QVERIFY(expectedUrls.removeOne(QStringLiteral("remote:/")));
     QTest::newRow("just_home_version_2") << (QByteArray(contentsPart1) + versionXml + contentsPart2) << expectedUrls;
-
 }
 
 void KFilePlacesModelTest::testAddingInLaterVersion()
@@ -308,23 +298,29 @@ void KFilePlacesModelTest::testAddingInLaterVersion()
     delete m_places2;
     QCoreApplication::processEvents();
 
-    KBookmarkManager *mgr = KBookmarkManager::managerForExternalFile(bookmarksFile());
+    KBookmarkManager mgr(bookmarksFile());
 
-    auto cleanupFunc = [this, mgr]() {
+    auto cleanupFunc = [this, &mgr]() {
         QFile::remove(bookmarksFile());
         // let KDirWatch process the deletion
-        QTRY_VERIFY(mgr->root().first().isNull());
+        QTRY_VERIFY(mgr.root().first().isNull());
         createPlacesModels();
         testInitialList();
     };
     struct Cleanup {
-        explicit Cleanup(const std::function<void()> &f) : func(f) {}
-        ~Cleanup() { func(); }
+        explicit Cleanup(const std::function<void()> &f)
+            : func(f)
+        {
+        }
+        ~Cleanup()
+        {
+            func();
+        }
         std::function<void()> func;
     } cleanup(cleanupFunc);
 
     QTest::qWait(1000); // for KDirWatch
-    QSignalSpy spy(mgr, &KBookmarkManager::changed);
+    QSignalSpy spy(&mgr, &KBookmarkManager::changed);
 
     // WHEN
     QFile file(bookmarksFile());
@@ -347,8 +343,7 @@ void KFilePlacesModelTest::testAddingInLaterVersion()
 void KFilePlacesModelTest::testReparse()
 {
     // add item
-    m_places->addPlace(QStringLiteral("foo"), QUrl::fromLocalFile(QStringLiteral("/foo")),
-                       QString(), QString());
+    m_places->addPlace(QStringLiteral("foo"), QUrl::fromLocalFile(QStringLiteral("/foo")), QString(), QString());
 
     QStringList urls = initialListOfUrls();
     // it will be added at the end of places section
@@ -356,8 +351,8 @@ void KFilePlacesModelTest::testReparse()
     CHECK_PLACES_URLS(urls);
 
     // reparse the bookmark file
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    bookmarkManager->notifyCompleteChange(QString());
+    KBookmarkManager bookmarkManager(bookmarksFile());
+    bookmarkManager.notifyCompleteChange(QString());
 
     // check if they are the same
     CHECK_PLACES_URLS(urls);
@@ -371,8 +366,8 @@ void KFilePlacesModelTest::testReparse()
 
 void KFilePlacesModelTest::testInternalBookmarksHaveIds()
 {
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    KBookmarkGroup root = bookmarkManager->root();
+    KBookmarkManager bookmarkManager(bookmarksFile());
+    KBookmarkGroup root = bookmarkManager.root();
 
     // Verify every entry has an id or an udi
     KBookmark bookmark = root.first();
@@ -393,7 +388,7 @@ void KFilePlacesModelTest::testInternalBookmarksHaveIds()
     KBookmark foo = root.addBookmark(QStringLiteral("Foo"), QUrl(QStringLiteral("file:/foo")), QStringLiteral("red-folder"));
     QCOMPARE(foo.text(), QStringLiteral("Foo"));
     QVERIFY(foo.metaDataItem(QStringLiteral("ID")).isEmpty());
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
     QCOMPARE(foo.text(), QStringLiteral("Foo"));
     QVERIFY(!foo.metaDataItem(QStringLiteral("ID")).isEmpty());
 
@@ -422,7 +417,7 @@ void KFilePlacesModelTest::testInternalBookmarksHaveIds()
 
     // Cleanup foo
     root.deleteBookmark(foo);
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
 }
 
 void KFilePlacesModelTest::testHiding()
@@ -481,8 +476,8 @@ void KFilePlacesModelTest::testMove()
     QSignalSpy spy_inserted(m_places, &QAbstractItemModel::rowsInserted);
     QSignalSpy spy_removed(m_places, &QAbstractItemModel::rowsRemoved);
 
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    KBookmarkGroup root = bookmarkManager->root();
+    KBookmarkManager bookmarkManager(bookmarksFile());
+    KBookmarkGroup root = bookmarkManager.root();
 
     KBookmark system_home = m_places->bookmarkForIndex(m_places->index(0, 0));
 
@@ -493,13 +488,10 @@ void KFilePlacesModelTest::testMove()
         last = root.next(last);
     }
     root.moveBookmark(system_home, last);
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
 
     QStringList urls;
-    urls << QStringLiteral("trash:/") << QDir::homePath()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
+    urls << QStringLiteral("trash:/") << QDir::homePath() << initialListOfShared() << initialListOfRecent() << initialListOfDevices()
          << initialListOfRemovableDevices();
 
     CHECK_PLACES_URLS(urls);
@@ -516,13 +508,9 @@ void KFilePlacesModelTest::testMove()
 
     // Move home at the beginning of the list (at its original place)
     root.moveBookmark(system_home, KBookmark());
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
@@ -536,7 +524,6 @@ void KFilePlacesModelTest::testMove()
     QCOMPARE(args.at(2).toInt(), 0);
 }
 
-
 void KFilePlacesModelTest::testDragAndDrop()
 {
     QList<QVariant> args;
@@ -547,7 +534,6 @@ void KFilePlacesModelTest::testDragAndDrop()
     QSignalSpy spy_inserted(m_places, &QAbstractItemModel::rowsInserted);
     QSignalSpy spy_removed(m_places, &QAbstractItemModel::rowsRemoved);
 
-
     // Move /home at the end of the places list
     QModelIndexList indexes;
     indexes << m_places->index(0, 0);
@@ -555,10 +541,7 @@ void KFilePlacesModelTest::testDragAndDrop()
     QVERIFY(m_places->dropMimeData(mimeData, Qt::MoveAction, 2, 0, QModelIndex()));
 
     QStringList urls;
-    urls << QStringLiteral("trash:/") << QDir::homePath()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
+    urls << QStringLiteral("trash:/") << QDir::homePath() << initialListOfShared() << initialListOfRecent() << initialListOfDevices()
          << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
@@ -578,10 +561,7 @@ void KFilePlacesModelTest::testDragAndDrop()
     QVERIFY(m_places->dropMimeData(mimeData, Qt::MoveAction, 0, 0, QModelIndex()));
 
     urls.clear();
-    urls << QDir::homePath() << QStringLiteral("trash:/")
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
+    urls << QDir::homePath() << QStringLiteral("trash:/") << initialListOfShared() << initialListOfRecent() << initialListOfDevices()
          << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
@@ -615,10 +595,7 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     m_places->addPlace(QStringLiteral("Foo"), QUrl::fromLocalFile(QStringLiteral("/home/foo")));
 
     QStringList urls;
-    urls << initialListOfPlaces() <<  QStringLiteral("/home/foo")
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
+    urls << initialListOfPlaces() << QStringLiteral("/home/foo") << initialListOfShared() << initialListOfRecent() << initialListOfDevices()
          << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
@@ -628,20 +605,17 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     QCOMPARE(args.at(2).toInt(), 2);
     QCOMPARE(spy_removed.count(), 0);
 
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    KBookmarkGroup root = bookmarkManager->root();
+    KBookmarkManager bookmarkManager(bookmarksFile());
+    KBookmarkGroup root = bookmarkManager.root();
     KBookmark before_trash = m_places->bookmarkForIndex(m_places->index(0, 0));
     KBookmark foo = m_places->bookmarkForIndex(m_places->index(2, 0));
 
     root.moveBookmark(foo, before_trash);
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
 
     urls.clear();
-    urls << QDir::homePath() << QStringLiteral("/home/foo") << QStringLiteral("trash:/")
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << QDir::homePath() << QStringLiteral("/home/foo") << QStringLiteral("trash:/") << initialListOfShared() << initialListOfRecent()
+         << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
@@ -657,11 +631,8 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     m_places->editPlace(m_places->index(1, 0), QStringLiteral("Foo"), QUrl::fromLocalFile(QStringLiteral("/mnt/foo")));
 
     urls.clear();
-    urls << QDir::homePath() << QStringLiteral("/mnt/foo") << QStringLiteral("trash:/")
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << QDir::homePath() << QStringLiteral("/mnt/foo") << QStringLiteral("trash:/") << initialListOfShared() << initialListOfRecent()
+         << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
@@ -672,14 +643,11 @@ void KFilePlacesModelTest::testPlacesLifecycle()
 
     foo = m_places->bookmarkForIndex(m_places->index(1, 0));
     foo.setFullText(QStringLiteral("Bar"));
-    bookmarkManager->notifyCompleteChange(QString());
+    bookmarkManager.notifyCompleteChange(QString());
 
     urls.clear();
-    urls << QDir::homePath() << QStringLiteral("/mnt/foo") << QStringLiteral("trash:/")
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << QDir::homePath() << QStringLiteral("/mnt/foo") << QStringLiteral("trash:/") << initialListOfShared() << initialListOfRecent()
+         << initialListOfDevices() << initialListOfRemovableDevices();
 
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
@@ -693,11 +661,7 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     m_places->removePlace(m_places->index(1, 0));
 
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 1);
@@ -709,11 +673,8 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     m_places->addPlace(QStringLiteral("Foo"), QUrl::fromLocalFile(QStringLiteral("/home/foo")), QString(), QString(), m_places->index(0, 0));
 
     urls.clear();
-    urls << QDir::homePath() << QStringLiteral("/home/foo") << QStringLiteral("trash:/")
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << QDir::homePath() << QStringLiteral("/home/foo") << QStringLiteral("trash:/") << initialListOfShared() << initialListOfRecent()
+         << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
@@ -734,11 +695,8 @@ void KFilePlacesModelTest::testDevicePlugging()
     fakeManager()->call(QStringLiteral("unplug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     QStringList urls;
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << QStringLiteral("/media/floppy0")  << QStringLiteral("/media/cdrom");
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << QStringLiteral("/media/floppy0")
+         << QStringLiteral("/media/cdrom");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 1);
@@ -750,11 +708,7 @@ void KFilePlacesModelTest::testDevicePlugging()
     fakeManager()->call(QStringLiteral("plug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
@@ -765,8 +719,8 @@ void KFilePlacesModelTest::testDevicePlugging()
 
     // Move the device in the list, and check that it memorizes the position across plug/unplug
 
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    KBookmarkGroup root = bookmarkManager->root();
+    KBookmarkManager bookmarkManager(bookmarksFile());
+    KBookmarkGroup root = bookmarkManager.root();
     KBookmark before_floppy;
 
     KBookmark device = root.first(); // The device we'll move is the 6th bookmark
@@ -781,14 +735,11 @@ void KFilePlacesModelTest::testDevicePlugging()
     }
 
     root.moveBookmark(device, before_floppy);
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
 
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom");
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << QStringLiteral("/media/XO-Y4")
+         << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
@@ -804,11 +755,8 @@ void KFilePlacesModelTest::testDevicePlugging()
     fakeManager()->call(QStringLiteral("unplug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom");
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << QStringLiteral("/media/floppy0")
+         << QStringLiteral("/media/cdrom");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 1);
@@ -820,10 +768,7 @@ void KFilePlacesModelTest::testDevicePlugging()
     fakeManager()->call(QStringLiteral("plug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices() << QStringLiteral("/media/XO-Y4")
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << QStringLiteral("/media/XO-Y4")
          << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
@@ -838,14 +783,10 @@ void KFilePlacesModelTest::testDevicePlugging()
         seventh = root.next(seventh);
     }
     root.moveBookmark(device, seventh);
-    bookmarkManager->emitChanged(root);
+    bookmarkManager.emitChanged(root);
 
     urls.clear();
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
@@ -882,26 +823,21 @@ void KFilePlacesModelTest::testDeviceSetupTeardown()
 void KFilePlacesModelTest::testEnableBaloo()
 {
     KConfig config(QStringLiteral("baloofilerc"));
-    KConfigGroup basicSettings = config.group("Basic Settings");
+    KConfigGroup basicSettings = config.group(QStringLiteral("Basic Settings"));
     basicSettings.writeEntry("Indexing-Enabled", true);
     config.sync();
 
     KFilePlacesModel places_with_baloo;
     QStringList urls;
-     for (int row = 0; row < places_with_baloo.rowCount(); ++row) {
-         QModelIndex index = places_with_baloo.index(row, 0);
-         urls << places_with_baloo.url(index).toDisplayString(QUrl::PreferLocalFile);
+    for (int row = 0; row < places_with_baloo.rowCount(); ++row) {
+        QModelIndex index = places_with_baloo.index(row, 0);
+        urls << places_with_baloo.url(index).toDisplayString(QUrl::PreferLocalFile);
     }
 
     if (m_hasRecentlyUsedKio) {
         QVERIFY(urls.contains("recentlyused:/files"));
         QVERIFY(urls.contains("recentlyused:/locations"));
     }
-
-    QVERIFY(urls.contains("search:/documents"));
-    QVERIFY(urls.contains("search:/images"));
-    QVERIFY(urls.contains("search:/audio"));
-    QVERIFY(urls.contains("search:/videos"));
 }
 
 void KFilePlacesModelTest::testRemoteUrls_data()
@@ -932,11 +868,8 @@ void KFilePlacesModelTest::testRemoteUrls()
     // check if url list is correct after insertion
     QStringList urls;
     urls << QDir::homePath() << QStringLiteral("trash:/") // places
-         << QStringLiteral("remote:/") << QStringLiteral("/media/nfs")
-         << url.toString()
-         << initialListOfRecent()
-         << QStringLiteral("/foreign")
-         << QStringLiteral("/media/floppy0")  << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom");
+         << QStringLiteral("remote:/") << QStringLiteral("/media/nfs") << url.toString() << initialListOfRecent() << QStringLiteral("/foreign")
+         << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom");
     CHECK_PLACES_URLS(urls);
 
     // check if the new url was inserted in the right position (end of "Remote" section)
@@ -955,8 +888,8 @@ void KFilePlacesModelTest::testRemoteUrls()
 
 void KFilePlacesModelTest::testRefresh()
 {
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    KBookmarkGroup root = bookmarkManager->root();
+    KBookmarkManager bookmarkManager(bookmarksFile());
+    KBookmarkGroup root = bookmarkManager.root();
     KBookmark homePlace = root.first();
     const QModelIndex homePlaceIndex = m_places->index(0, 0);
 
@@ -977,15 +910,12 @@ void KFilePlacesModelTest::testConvertedUrl_data()
     QTest::addColumn<QUrl>("expectedUrl");
 
     // places
-    QTest::newRow("Places - Home") << QUrl::fromLocalFile(QDir::homePath())
-                                   << QUrl::fromLocalFile(QDir::homePath());
+    QTest::newRow("Places - Home") << QUrl::fromLocalFile(QDir::homePath()) << QUrl::fromLocalFile(QDir::homePath());
 
     // baloo -search
-    QTest::newRow("Baloo - Documents") << QUrl("search:/documents")
-                                       << QUrl("baloosearch:/documents");
+    QTest::newRow("Baloo - Documents") << QUrl("search:/documents") << QUrl("baloosearch:/documents");
 
-    QTest::newRow("Baloo - Unknown Type") << QUrl("search:/unknown")
-                                          << QUrl("search:/unknown");
+    QTest::newRow("Baloo - Unknown Type") << QUrl("search:/unknown") << QUrl("search:/unknown");
 
     // baloo - timeline
     const QDate lastMonthDate = QDate::currentDate().addMonths(-1);
@@ -993,8 +923,7 @@ void KFilePlacesModelTest::testConvertedUrl_data()
                                         << QUrl(QString("timeline:/%1-%2").arg(lastMonthDate.year()).arg(lastMonthDate.month(), 2, 10, QLatin1Char('0')));
 
     // devices
-    QTest::newRow("Devices - Floppy") << QUrl("file:///media/floppy0")
-                                      << QUrl("file:///media/floppy0");
+    QTest::newRow("Devices - Floppy") << QUrl("file:///media/floppy0") << QUrl("file:///media/floppy0");
 }
 
 void KFilePlacesModelTest::testConvertedUrl()
@@ -1011,7 +940,7 @@ void KFilePlacesModelTest::testConvertedUrl()
 
 void KFilePlacesModelTest::testBookmarkObject()
 {
-    //make sure that all items return a valid bookmark
+    // make sure that all items return a valid bookmark
     for (int row = 0; row < m_places->rowCount(); row++) {
         const QModelIndex index = m_places->index(row, 0);
         const KBookmark bookmark = m_places->bookmarkForIndex(index);
@@ -1054,27 +983,18 @@ void KFilePlacesModelTest::testIconRole_data()
 
     // places
     int index = 0;
-    QTest::newRow("Places - Home") << m_places->index(index++, 0)
-                                   << QStringLiteral("user-home");
-    QTest::newRow("Places - Trash") << m_places->index(index++, 0)
-                                   << QStringLiteral("user-trash");
+    QTest::newRow("Places - Home") << m_places->index(index++, 0) << QStringLiteral("user-home");
+    QTest::newRow("Places - Trash") << m_places->index(index++, 0) << QStringLiteral("user-trash");
 
-    QTest::newRow("Remote - Network") << m_places->index(index++, 0)
-                                    << QStringLiteral("folder-network");
-    QTest::newRow("Devices - Nfs") << m_places->index(index++, 0)
-                                    << QStringLiteral("hwinfo");
+    QTest::newRow("Remote - Network") << m_places->index(index++, 0) << QStringLiteral("folder-network");
+    QTest::newRow("Devices - Nfs") << m_places->index(index++, 0) << QStringLiteral("hwinfo");
     if (m_hasRecentlyUsedKio) {
-        QTest::newRow("Recent Files") << m_places->index(index++, 0)
-                                        << QStringLiteral("document-open-recent");
-        QTest::newRow("Recent Locations") << m_places->index(index++, 0)
-                                        << QStringLiteral("folder-open-recent");
+        QTest::newRow("Recent Files") << m_places->index(index++, 0) << QStringLiteral("document-open-recent");
+        QTest::newRow("Recent Locations") << m_places->index(index++, 0) << QStringLiteral("folder-open-recent");
     }
-    QTest::newRow("Devices - foreign") << m_places->index(index++, 0)
-                                    << QStringLiteral("blockdevice");
-    QTest::newRow("Devices - Floppy") << m_places->index(index++, 0)
-                                    << QStringLiteral("blockdevice");
-    QTest::newRow("Devices - cdrom") << m_places->index(index++, 0)
-                                    << QStringLiteral("blockdevice");
+    QTest::newRow("Devices - foreign") << m_places->index(index++, 0) << QStringLiteral("blockdevice");
+    QTest::newRow("Devices - Floppy") << m_places->index(index++, 0) << QStringLiteral("blockdevice");
+    QTest::newRow("Devices - cdrom") << m_places->index(index++, 0) << QStringLiteral("blockdevice");
 }
 
 void KFilePlacesModelTest::testIconRole()
@@ -1136,13 +1056,13 @@ void KFilePlacesModelTest::testMoveFunction()
     QCOMPARE(placesUrls(), urls);
     rowsMoved.clear();
 
-    QVERIFY(m_places->movePlace(m_hasRecentlyUsedKio ? 8: 7, m_hasRecentlyUsedKio ? 6 : 5));
-    urls.move(m_hasRecentlyUsedKio ? 8: 7, m_hasRecentlyUsedKio ? 6 : 5);
+    QVERIFY(m_places->movePlace(m_hasRecentlyUsedKio ? 8 : 7, m_hasRecentlyUsedKio ? 6 : 5));
+    urls.move(m_hasRecentlyUsedKio ? 8 : 7, m_hasRecentlyUsedKio ? 6 : 5);
     QTRY_COMPARE(rowsMoved.count(), 1);
     args = rowsMoved.takeFirst();
-    QCOMPARE(args.at(1).toInt(), m_hasRecentlyUsedKio ? 8: 7); // start
-    QCOMPARE(args.at(2).toInt(), m_hasRecentlyUsedKio ? 8: 7); // end
-    QCOMPARE(args.at(4).toInt(), m_hasRecentlyUsedKio ? 6: 5); // row (destination)
+    QCOMPARE(args.at(1).toInt(), m_hasRecentlyUsedKio ? 8 : 7); // start
+    QCOMPARE(args.at(2).toInt(), m_hasRecentlyUsedKio ? 8 : 7); // end
+    QCOMPARE(args.at(4).toInt(), m_hasRecentlyUsedKio ? 6 : 5); // row (destination)
     QCOMPARE(placesUrls(), urls);
     rowsMoved.clear();
 
@@ -1157,11 +1077,11 @@ void KFilePlacesModelTest::testMoveFunction()
     QCOMPARE(placesUrls(), urls);
     rowsMoved.clear();
 
-    //use a invalid start position
+    // use a invalid start position
     QVERIFY(!m_places->movePlace(100, 20));
     QCOMPARE(rowsMoved.count(), 0);
 
-    //use same start and target position
+    // use same start and target position
     QVERIFY(!m_places->movePlace(1, 1));
     QCOMPARE(rowsMoved.count(), 0);
 }
@@ -1172,13 +1092,9 @@ void KFilePlacesModelTest::testPlaceGroupHidden()
     QCOMPARE(m_places->hiddenCount(), 0);
 
     QStringList urls;
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
-    QVector<QModelIndex> indexesHidden;
+    QList<QModelIndex> indexesHidden;
 
     // WHEN
     m_places->setGroupHidden(KFilePlacesModel::PlacesType, true);
@@ -1195,7 +1111,7 @@ void KFilePlacesModelTest::testPlaceGroupHidden()
     QCOMPARE(m_places->hiddenCount(), indexesHidden.size());
 
     // and GIVEN
-    QVector<QModelIndex> indexesShown;
+    QList<QModelIndex> indexesShown;
 
     // WHEN
     m_places->setGroupHidden(KFilePlacesModel::PlacesType, false);
@@ -1221,7 +1137,7 @@ void KFilePlacesModelTest::testPlaceGroupHiddenVsPlaceChildShown()
     }
     m_places->setGroupHidden(KFilePlacesModel::PlacesType, true);
 
-    QModelIndex firstIndex = m_places->index(0,0);
+    QModelIndex firstIndex = m_places->index(0, 0);
     const int amountOfPlaces = initialListOfPlaces().size();
     for (int row = 0; row < amountOfPlaces; ++row) {
         QModelIndex index = m_places->index(row, 0);
@@ -1243,14 +1159,10 @@ void KFilePlacesModelTest::testPlaceGroupHiddenAndShownWithHiddenChild()
     QCOMPARE(m_places->hiddenCount(), 0);
 
     QStringList urls;
-    urls << initialListOfPlaces()
-         << initialListOfShared()
-         << initialListOfRecent()
-         << initialListOfDevices()
-         << initialListOfRemovableDevices();
+    urls << initialListOfPlaces() << initialListOfShared() << initialListOfRecent() << initialListOfDevices() << initialListOfRemovableDevices();
     CHECK_PLACES_URLS(urls);
 
-    QModelIndex firstIndexHidden = m_places->index(0,0);
+    QModelIndex firstIndexHidden = m_places->index(0, 0);
     m_places->setPlaceHidden(firstIndexHidden, true); // first place index is hidden within an hidden parent
     m_places->setGroupHidden(KFilePlacesModel::PlacesType, true);
     QCOMPARE(m_places->hiddenCount(), initialListOfPlaces().size());
@@ -1259,7 +1171,7 @@ void KFilePlacesModelTest::testPlaceGroupHiddenAndShownWithHiddenChild()
     m_places->setGroupHidden(KFilePlacesModel::PlacesType, false);
 
     // THEN
-    QVector<QModelIndex> indexesShown;
+    QList<QModelIndex> indexesShown;
     for (int row = 0; row < m_places->rowCount(); ++row) {
         QModelIndex index = m_places->index(row, 0);
         if (index == firstIndexHidden) {
@@ -1290,7 +1202,7 @@ void KFilePlacesModelTest::testPlaceGroupHiddenGroupIndexesIntegrity()
     QCOMPARE(m_places->groupIndexes(KFilePlacesModel::DevicesType).count(), initialListOfDevices().count());
     QCOMPARE(m_places->groupIndexes(KFilePlacesModel::RemovableDevicesType).count(), initialListOfRemovableDevices().count());
 
-    //WHEN
+    // WHEN
     m_places->setGroupHidden(KFilePlacesModel::PlacesType, false);
 
     // THEN
@@ -1358,30 +1270,6 @@ void KFilePlacesModelTest::testPlaceGroupHiddenRole()
     }
 }
 
-void KFilePlacesModelTest::testFilterWithAlternativeApplicationName()
-{
-    const QStringList urls = initialListOfUrls();
-    const QString alternativeApplicationName = QStringLiteral("kfile_places_model_test");
-
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
-    KBookmarkGroup root = bookmarkManager->root();
-
-    // create a new entry with alternative application name
-    KBookmark bookmark = root.addBookmark(QStringLiteral("Extra entry"), QUrl(QStringLiteral("search:/videos-alternative")), {});
-    const QString id = QUuid::createUuid().toString();
-    bookmark.setMetaDataItem(QStringLiteral("ID"), id);
-    bookmark.setMetaDataItem(QStringLiteral("OnlyInApp"), alternativeApplicationName);
-    bookmarkManager->emitChanged(bookmarkManager->root());
-
-    // make sure that the entry is not visible on the original model
-    CHECK_PLACES_URLS(urls);
-
-    // create a new model with alternativeApplicationName
-    KFilePlacesModel *newModel = new KFilePlacesModel(alternativeApplicationName);
-    QTRY_COMPARE(placesUrls(newModel).count(QStringLiteral("search:/videos-alternative")), 1);
-    delete newModel;
-}
-
 void KFilePlacesModelTest::testSupportedSchemes()
 {
     QCoreApplication::processEvents(); // support running this test on its own
