@@ -67,10 +67,6 @@ private Q_SLOTS:
     void testGetStartUrl();
     void testSetSelection_data();
 
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 33)
-    void testSetSelection();
-#endif
-
     void testSetSelectedUrl_data();
     void testSetSelectedUrl();
     void testPreserveFilenameWhileNavigating();
@@ -86,6 +82,8 @@ private Q_SLOTS:
     void testCreateNestedNewFolders();
     void testTokenize_data();
     void testTokenize();
+    void testTokenizeForSave_data();
+    void testTokenizeForSave();
 };
 
 void KFileWidgetTest::initTestCase()
@@ -101,59 +99,64 @@ void KFileWidgetTest::testFilterCombo()
     fw.setOperationMode(KFileWidget::Saving);
     fw.setMode(KFile::File);
 
-    fw.setFilter(
-        QStringLiteral("*.xml *.a|Word 2003 XML (.xml)\n"
-                       "*.odt|ODF Text Document (.odt)\n"
-                       "*.xml *.b|DocBook (.xml)\n"
-                       "*|Raw (*)"));
+    const KFileFilter wordFilter = KFileFilter::fromFilterString("*.xml *.a|Word 2003 XML (.xml)").first();
+    const KFileFilter odtFilter = KFileFilter::fromFilterString("*.odt|ODF Text Document (.odt)").first();
+    const KFileFilter docBookFilter = KFileFilter::fromFilterString("*.xml *.b|DocBook (.xml)").first();
+    const KFileFilter rawFilter = KFileFilter::fromFilterString("*|Raw (*)").first();
+
+    fw.setFilters({wordFilter, odtFilter, docBookFilter, rawFilter});
 
     // default filter is selected
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.xml *.a"));
+    QCOMPARE(fw.currentFilter(), wordFilter);
 
     // setUrl runs with blocked signals, so use setUrls.
     // auto-select ODT filter via filename
     fw.locationEdit()->setUrls(QStringList(QStringLiteral("test.odt")));
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.odt"));
+    QCOMPARE(fw.currentFilter(), odtFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.odt"));
 
     // select 2nd duplicate XML filter (see bug 407642)
-    fw.filterWidget()->setCurrentFilter("*.xml *.b|DocBook (.xml)");
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.xml *.b"));
+    fw.filterWidget()->setCurrentFilter(docBookFilter);
+    QCOMPARE(fw.currentFilter(), docBookFilter);
+    // when editing the filter, there is delay to avoid refreshing the KDirOperator after each keypress
+    QTest::qWait(350);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.xml"));
 
     // keep filter after file change with same extension
     fw.locationEdit()->setUrls(QStringList(QStringLiteral("test2.xml")));
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.xml *.b"));
+    QCOMPARE(fw.currentFilter(), docBookFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test2.xml"));
 
     // back to the non-xml / ODT filter
     fw.locationEdit()->setUrls(QStringList(QStringLiteral("test.odt")));
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.odt"));
+    QCOMPARE(fw.currentFilter(), odtFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.odt"));
 
     // auto-select 1st XML filter
     fw.locationEdit()->setUrls(QStringList(QStringLiteral("test.xml")));
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.xml *.a"));
+    QCOMPARE(fw.currentFilter(), wordFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.xml"));
 
     // select Raw '*' filter
-    fw.filterWidget()->setCurrentFilter("*|Raw (*)");
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*"));
+    fw.filterWidget()->setCurrentFilter(rawFilter);
+    QCOMPARE(fw.currentFilter(), rawFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.xml"));
 
     // keep Raw '*' filter with matching file extension
     fw.locationEdit()->setUrls(QStringList(QStringLiteral("test.odt")));
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*"));
+    QCOMPARE(fw.currentFilter(), rawFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.odt"));
 
     // keep Raw '*' filter with non-matching file extension
     fw.locationEdit()->setUrls(QStringList(QStringLiteral("test.core")));
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*"));
+    QCOMPARE(fw.currentFilter(), rawFilter);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.core"));
 
     // select 2nd XML filter
-    fw.filterWidget()->setCurrentFilter("*.xml *.b|DocBook (.xml)");
-    QCOMPARE(fw.currentFilter(), QStringLiteral("*.xml *.b"));
+    fw.filterWidget()->setCurrentFilter(docBookFilter);
+    QCOMPARE(fw.currentFilter(), docBookFilter);
+    // when editing the filter, there is delay to avoid refreshing the KDirOperator after each keypress
+    QTest::qWait(350);
     QCOMPARE(fw.locationEdit()->urls()[0], QStringLiteral("test.xml"));
 }
 
@@ -223,13 +226,8 @@ void KFileWidgetTest::testGetStartUrl()
     QCOMPARE(localUrl.toLocalFile(), QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
     QVERIFY(outFileName.isEmpty());
 
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 96)
-    localUrl = KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///attachments/foo.txt?global")), recentDirClass, outFileName);
-    QCOMPARE(recentDirClass, QStringLiteral("::attachments"));
-#else
     localUrl = KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///attachments/foo.txt")), recentDirClass, outFileName);
     QCOMPARE(recentDirClass, QStringLiteral(":attachments"));
-#endif
     QCOMPARE(localUrl.toLocalFile(), QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
     QCOMPARE(outFileName, QStringLiteral("foo.txt"));
 }
@@ -254,31 +252,6 @@ void KFileWidgetTest::testSetSelection_data()
     QTest::newRow("filename") << baseDir << fileName << baseDir << fileName;
 }
 
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 33)
-void KFileWidgetTest::testSetSelection()
-{
-    // GIVEN
-    QFETCH(QString, baseDir);
-    QFETCH(QString, selection);
-    QFETCH(QString, expectedBaseDir);
-    QFETCH(QString, expectedCurrentText);
-    const QUrl baseUrl = QUrl::fromLocalFile(baseDir).adjusted(QUrl::StripTrailingSlash);
-    const QUrl expectedBaseUrl = QUrl::fromLocalFile(expectedBaseDir);
-
-    KFileWidget fw(baseUrl);
-
-    // WHEN
-    fw.setSelection(selection); // now deprecated, this test shows why ;)
-
-    // THEN
-    QCOMPARE(fw.baseUrl().adjusted(QUrl::StripTrailingSlash), expectedBaseUrl);
-    // if (QByteArray(QTest::currentDataTag()) == "filename") {
-    QEXPECT_FAIL("filename", "setSelection cannot work with filenames, bad API", Continue);
-    //}
-    QCOMPARE(fw.locationEdit()->currentText(), expectedCurrentText);
-}
-#endif
-
 void KFileWidgetTest::testSetSelectedUrl_data()
 {
     QTest::addColumn<QString>("baseDir");
@@ -419,7 +392,7 @@ void KFileWidgetTest::testSetFilterForSave()
     fw.setOperationMode(KFileWidget::Saving);
     fw.setSelectedUrl(fileUrl);
     // Calling setFilter has side-effects and changes the file name.
-    fw.setFilter(filter);
+    fw.setFilters(KFileFilter::fromFilterString(filter));
 
     // Verify the expected populated name.
     QCOMPARE(fw.baseUrl().adjusted(QUrl::StripTrailingSlash), dirUrl);
@@ -477,7 +450,7 @@ void KFileWidgetTest::testExtensionForSave()
     // Calling setFilter has side-effects and changes the file name.
     // The difference to testSetFilterForSave is that the filter is already set before the fileUrl
     // is set, and will not be changed after.
-    fw.setFilter(filter);
+    fw.setFilters(KFileFilter::fromFilterString(filter));
     fw.setSelectedUrl(fileUrl);
 
     // Verify the expected populated name.
@@ -504,22 +477,25 @@ void KFileWidgetTest::testFilterChange()
     KFileWidget fw(QUrl::fromLocalFile(tempDir.path()));
     fw.setOperationMode(KFileWidget::Saving);
     fw.setSelectedUrl(QUrl::fromLocalFile(tempDir.filePath("some.txt")));
-    fw.setFilter("*.txt|Txt\n*.c|C");
+    const QList<KFileFilter> filters = KFileFilter::fromFilterString("*.txt|Txt\n*.c|C");
+    fw.setFilters(filters);
 
     // Initial filename.
     QCOMPARE(fw.locationEdit()->currentText(), QStringLiteral("some.txt"));
-    QCOMPARE(fw.filterWidget()->currentFilter(), QStringLiteral("*.txt"));
+    QCOMPARE(fw.filterWidget()->currentFilter(), filters[0]);
 
     // Select type with an existing file.
-    fw.filterWidget()->setCurrentFilter("*.c|C");
+    fw.filterWidget()->setCurrentFilter(filters[1]);
+    // when editing the filter, there is delay to avoid refreshing the KDirOperator after each keypress
+    QTest::qWait(350);
     QCOMPARE(fw.locationEdit()->currentText(), QStringLiteral("some.c"));
-    QCOMPARE(fw.filterWidget()->currentFilter(), QStringLiteral("*.c"));
+    QCOMPARE(fw.filterWidget()->currentFilter(), filters[1]);
 
     // Do not update extension if the current selection is a directory.
     fw.setSelectedUrl(QUrl::fromLocalFile(tempDir.filePath("directory")));
-    fw.filterWidget()->setCurrentFilter("*.txt|Txt");
+    fw.filterWidget()->setCurrentFilter(filters[0]);
     QCOMPARE(fw.locationEdit()->currentText(), QStringLiteral("directory"));
-    QCOMPARE(fw.filterWidget()->currentFilter(), QStringLiteral("*.txt"));
+    QCOMPARE(fw.filterWidget()->currentFilter(), filters[0]);
 }
 
 void KFileWidgetTest::testDropFile_data()
@@ -750,6 +726,112 @@ void KFileWidgetTest::testTokenize()
     QCOMPARE(urls, fileUrls);
 }
 
+void KFileWidgetTest::testTokenizeForSave_data()
+{
+    // Real filename (as in how they are stored in the fs)
+    QTest::addColumn<QString>("fileName");
+    // Escaped value of the text-box in the dialog
+    // Escaped cwd: Because setSelectedUrl is called in this
+    // test, it actually sets the CWD to the dirname and only
+    // keeps the filename displayed in the test
+    QTest::addColumn<QString>("expectedSubFolder");
+    QTest::addColumn<QString>("expectedCurrentText");
+
+    QTest::newRow("save-simple") << QString{"test2"} << QString() << QString("test2");
+
+    // When a single file with space is selected, it is _not_ quoted ...
+    QTest::newRow("save-space") << QString{"test space"} << QString() << QString("test space");
+
+    // All quotes in names should be escaped, however since this is a single
+    // file, the whole name will not be escaped.
+    QTest::newRow("save-quote") << QString{"test\"quote"} << QString() << QString("test\\\"quote");
+
+    // Ok, enough with quotes... lets do some backslashes
+    // Backslash literals in file names - Unix only case
+    QTest::newRow("save-backslash") << QString{"test\\backslash"} << QString() << QString("test\\\\backslash");
+
+    QTest::newRow("save-double-backslash") << QString{"test\\\\back\\slash"} << QString() << QString("test\\\\\\\\back\\\\slash");
+
+    QTest::newRow("save-double-backslash-end") << QString{"test\\\\"} << QString() << QString("test\\\\\\\\");
+
+    QTest::newRow("save-single-backslash-end") << QString{"test\\"} << QString() << QString("test\\\\");
+
+    QTest::newRow("save-sharp") << QString{"some#thing"} << QString() << QString("some#thing");
+
+    // Filenames beginning with ':'; QDir::isAbsolutePath() always returns true
+    // in that case, #322837
+    QTest::newRow("save-file-beginning-with-colon") << QString{":test2"} << QString() << QString{":test2"};
+
+    // # 473228
+    QTest::newRow("save-save-file-beginning-with-something-that-looks-like-a-url-scheme")
+        << QString{"Hello: foo.txt"} << QString() << QString{"Hello: foo.txt"};
+
+    QTemporaryDir otherTempDir;
+    otherTempDir.setAutoRemove(false);
+    const auto testFile1Path = otherTempDir.filePath("test-1");
+    createTestFile(testFile1Path);
+
+    QTest::newRow("save-absolute-url-not-in-dir") << QString{"file://" + testFile1Path} << otherTempDir.path() << QString{"test-1"};
+
+    auto expectedtestFile1Path = testFile1Path;
+    expectedtestFile1Path = expectedtestFile1Path.remove(0, 1);
+
+    QTest::newRow("save-absolute-url-not-in-dir-no-scheme") << QString{testFile1Path} << otherTempDir.path() << QString{"test-1"};
+}
+
+void KFileWidgetTest::testTokenizeForSave()
+{
+    // We will use setSelectedUrls([QUrl]) here in order to check correct
+    // filename escaping. Afterwards we will accept() the dialog to confirm
+    // correct result
+
+    // This test is similar to testTokenize but focuses on single-file
+    // "save" operation. This follows a different code-path internally
+    // and calls setSelectedUrl instead of setSelectedUrls.
+
+    QFETCH(QString, fileName);
+    QFETCH(QString, expectedSubFolder);
+    QFETCH(QString, expectedCurrentText);
+
+    QTemporaryDir tempDir;
+    const QString tempDirPath = tempDir.path();
+    const QUrl tempDirUrl = QUrl::fromLocalFile(tempDirPath);
+    auto fileUrl = QUrl(fileName);
+    if (!fileUrl.path().startsWith(QLatin1Char('/'))) {
+        const QString filePath = tempDirPath + QLatin1Char('/') + fileName;
+        fileUrl = QUrl::fromLocalFile(filePath);
+    }
+    if (fileUrl.scheme().isEmpty()) {
+        fileUrl.setScheme("file");
+    }
+    qCDebug(KIO_KFILEWIDGETS_FW) << fileName << " => " << fileUrl;
+
+    KFileWidget fw(tempDirUrl);
+    fw.setOperationMode(KFileWidget::Saving);
+    fw.setMode(KFile::File);
+    fw.setSelectedUrl(fileUrl);
+
+    // Verify the expected populated name.
+    if (expectedSubFolder != "") {
+        const QUrl expectedBaseUrl = tempDirUrl.resolved(QUrl::fromLocalFile(expectedSubFolder));
+        QCOMPARE(fw.baseUrl().adjusted(QUrl::StripTrailingSlash), expectedBaseUrl);
+    } else {
+        QCOMPARE(fw.baseUrl().adjusted(QUrl::StripTrailingSlash), tempDirUrl);
+    }
+    QCOMPARE(fw.locationEdit()->currentText(), expectedCurrentText);
+
+    // QFileDialog ends up calling KDEPlatformFileDialog::selectedFiles()
+    // which calls KFileWidget::selectedUrls().
+    // Accept the filename to ensure that a filename is selected.
+    connect(&fw, &KFileWidget::accepted, &fw, &KFileWidget::accept);
+    QTest::keyClick(fw.locationEdit(), Qt::Key_Return);
+    const QList<QUrl> urls = fw.selectedUrls();
+
+    // We always only have one URL here
+    QCOMPARE(urls.size(), 1);
+    QCOMPARE(urls[0], fileUrl);
+}
+
 QTEST_MAIN(KFileWidgetTest)
 
 #include "kfilewidgettest.moc"
