@@ -26,6 +26,7 @@
 #include <QFile>
 #include <QList>
 #include <QMap>
+#include <QSsl>
 #include <QtGlobal>
 
 #include <KConfig>
@@ -37,6 +38,7 @@
 #include <KCrash>
 #endif
 
+#include "authinfo.h"
 #include "kremoteencoding.h"
 
 #include "commands_p.h"
@@ -45,13 +47,16 @@
 #include "kiocoredebug.h"
 #include "kioglobal_p.h"
 #include "kpasswdserverclient.h"
-#include "slaveinterface.h"
+#include "workerinterface_p.h"
 
 #if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID)
 #include <KAuth/Action>
 #endif
 
-#if KIO_ASSERT_SLAVE_STATES
+// TODO: Enable once file KIO worker is ported away and add endif, similar in the header file
+// #if KIOCORE_BUILD_DEPRECATED_SINCE(version where file:/ KIO worker was ported)
+
+#if KIO_ASSERT_WORKER_STATES
 #define KIO_STATE_ASSERT(cond, where, what) Q_ASSERT_X(cond, where, what)
 #else
 /* clang-format off */
@@ -95,8 +100,12 @@ public:
         , m_confirmationAsked(false)
         , m_privilegeOperationStatus(OperationNotAllowed)
     {
-        if (!qEnvironmentVariableIsEmpty("KIOSLAVE_ENABLE_TESTMODE")) {
+        if (!qEnvironmentVariableIsEmpty("KIOWORKER_ENABLE_TESTMODE")) {
             QStandardPaths::setTestModeEnabled(true);
+        } else if (!qEnvironmentVariableIsEmpty("KIOSLAVE_ENABLE_TESTMODE")) {
+            QStandardPaths::setTestModeEnabled(true);
+            qCWarning(KIO_CORE)
+                << "KIOSLAVE_ENABLE_TESTMODE is deprecated for KF6, and will be unsupported soon. Please use KIOWORKER_ENABLE_TESTMODE with KF6.";
         }
         pendingListEntries.reserve(KIO_MAX_ENTRIES_PER_BATCH);
         appConnection.setReadMode(Connection::ReadMode::Polled);
@@ -128,7 +137,7 @@ public:
     qint64 nextTimeoutMsecs;
     KIO::filesize_t totalSize;
     KRemoteEncoding *remotefile = nullptr;
-    enum { Idle, InsideMethod, FinishedCalled, ErrorCalled } m_state;
+    enum { Idle, InsideMethod, InsideTimeoutSpecial, FinishedCalled, ErrorCalled } m_state;
     bool m_finalityCommand = true; // whether finished() or error() may/must be called
     QByteArray timeoutData;
 
@@ -193,9 +202,10 @@ public:
 
     void verifyState(const char *cmdName)
     {
+        Q_UNUSED(cmdName)
         KIO_STATE_ASSERT(finalState(),
                          Q_FUNC_INFO,
-                         qUtf8Printable(QStringLiteral("%1 did not call finished() or error()! Please fix the %2 KIO slave")
+                         qUtf8Printable(QStringLiteral("%1 did not call finished() or error()! Please fix the %2 KIO worker.")
                                             .arg(QLatin1String(cmdName))
                                             .arg(QCoreApplication::applicationName())));
         // Force the command into finished state. We'll not reach this for Debug builds
@@ -209,9 +219,10 @@ public:
 
     void verifyErrorFinishedNotCalled(const char *cmdName)
     {
+        Q_UNUSED(cmdName)
         KIO_STATE_ASSERT(!finalState(),
                          Q_FUNC_INFO,
-                         qUtf8Printable(QStringLiteral("%1 called finished() or error(), but it's not supposed to! Please fix the %2 KIO slave")
+                         qUtf8Printable(QStringLiteral("%1 called finished() or error(), but it's not supposed to! Please fix the %2 KIO worker.")
                                             .arg(QLatin1String(cmdName))
                                             .arg(QCoreApplication::applicationName())));
     }
@@ -313,8 +324,8 @@ void SlaveBase::dispatchLoop()
             QByteArray data = d->timeoutData;
             d->nextTimeout.invalidate();
             d->timeoutData = QByteArray();
+            d->m_state = d->InsideTimeoutSpecial;
             special(data);
-            // NB: not performing state validation since http slave is misbehaving and not emitting anything at the time of writing - August 2022
             d->m_state = d->Idle;
         }
 
@@ -358,7 +369,7 @@ void SlaveBase::dispatchLoop()
 
         // I think we get here when we were killed in dispatch() and not in select()
         if (wasKilled()) {
-            // qDebug() << "slave was killed, returning";
+            // qDebug() << "worker was killed, returning";
             break;
         }
 
@@ -503,21 +514,26 @@ void SlaveBase::opened()
 
 void SlaveBase::error(int _errid, const QString &_text)
 {
+    if (d->m_state == d->InsideTimeoutSpecial) {
+        qWarning(KIO_CORE) << "TimeoutSpecialCommand failed with" << _errid << _text;
+        return;
+    }
+
     KIO_STATE_ASSERT(
         d->m_finalityCommand,
         Q_FUNC_INFO,
-        qUtf8Printable(QStringLiteral("error() was called, but it's not supposed to! Please fix the %1 KIO slave").arg(QCoreApplication::applicationName())));
+        qUtf8Printable(QStringLiteral("error() was called, but it's not supposed to! Please fix the %1 KIO worker.").arg(QCoreApplication::applicationName())));
 
     if (d->m_state == d->ErrorCalled) {
         KIO_STATE_ASSERT(false,
                          Q_FUNC_INFO,
-                         qUtf8Printable(QStringLiteral("error() called twice! Please fix the %1 KIO slave").arg(QCoreApplication::applicationName())));
+                         qUtf8Printable(QStringLiteral("error() called twice! Please fix the %1 KIO worker.").arg(QCoreApplication::applicationName())));
         return;
     } else if (d->m_state == d->FinishedCalled) {
         KIO_STATE_ASSERT(
             false,
             Q_FUNC_INFO,
-            qUtf8Printable(QStringLiteral("error() called after finished()! Please fix the %1 KIO slave").arg(QCoreApplication::applicationName())));
+            qUtf8Printable(QStringLiteral("error() called after finished()! Please fix the %1 KIO worker.").arg(QCoreApplication::applicationName())));
         return;
     }
 
@@ -542,9 +558,13 @@ void SlaveBase::connected()
 
 void SlaveBase::finished()
 {
+    if (d->m_state == d->InsideTimeoutSpecial) {
+        return;
+    }
+
     if (!d->pendingListEntries.isEmpty()) {
         if (!d->m_rootEntryListed) {
-            qCWarning(KIO_CORE) << "UDSEntry for '.' not found, creating a default one. Please fix the" << QCoreApplication::applicationName() << "KIO slave";
+            qCWarning(KIO_CORE) << "UDSEntry for '.' not found, creating a default one. Please fix the" << QCoreApplication::applicationName() << "KIO worker.";
             KIO::UDSEntry entry;
             entry.reserve(4);
             entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
@@ -562,18 +582,18 @@ void SlaveBase::finished()
         d->m_finalityCommand,
         Q_FUNC_INFO,
         qUtf8Printable(
-            QStringLiteral("finished() was called, but it's not supposed to! Please fix the %2 KIO slave").arg(QCoreApplication::applicationName())));
+            QStringLiteral("finished() was called, but it's not supposed to! Please fix the %2 KIO worker.").arg(QCoreApplication::applicationName())));
 
     if (d->m_state == d->FinishedCalled) {
         KIO_STATE_ASSERT(false,
                          Q_FUNC_INFO,
-                         qUtf8Printable(QStringLiteral("finished() called twice! Please fix the %1 KIO slave").arg(QCoreApplication::applicationName())));
+                         qUtf8Printable(QStringLiteral("finished() called twice! Please fix the %1 KIO worker.").arg(QCoreApplication::applicationName())));
         return;
     } else if (d->m_state == d->ErrorCalled) {
         KIO_STATE_ASSERT(
             false,
             Q_FUNC_INFO,
-            qUtf8Printable(QStringLiteral("finished() called after error()! Please fix the %1 KIO slave").arg(QCoreApplication::applicationName())));
+            qUtf8Printable(QStringLiteral("finished() called after error()! Please fix the %1 KIO worker.").arg(QCoreApplication::applicationName())));
         return;
     }
 
@@ -591,17 +611,12 @@ void SlaveBase::finished()
     d->m_privilegeOperationStatus = OperationNotAllowed;
 }
 
-void SlaveBase::needSubUrlData()
-{
-    send(MSG_NEED_SUBURL_DATA);
-}
-
 void SlaveBase::slaveStatus(const QString &host, bool connected)
 {
     qint64 pid = getpid();
     qint8 b = connected ? 1 : 0;
     KIO_DATA << pid << mProtocol << host << b << d->onHold << d->onHoldUrl << d->hasTempAuth();
-    send(MSG_SLAVE_STATUS_V2, data);
+    send(MSG_WORKER_STATUS, data);
 }
 
 void SlaveBase::canResume()
@@ -687,11 +702,7 @@ static bool isSubCommand(int cmd)
     return cmd == CMD_REPARSECONFIGURATION
         || cmd == CMD_META_DATA
         || cmd == CMD_CONFIG
-        || cmd == CMD_SUBURL
-        || cmd == CMD_SLAVE_STATUS
-        || cmd == CMD_SLAVE_CONNECT
-        || cmd == CMD_SLAVE_HOLD
-        || cmd == CMD_MULTI_GET;
+        || cmd == CMD_WORKER_STATUS;
     /* clang-format on */
 }
 
@@ -758,54 +769,12 @@ void SlaveBase::infoMessage(const QString &_msg)
     send(INF_INFOMESSAGE, data);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
-bool SlaveBase::requestNetwork(const QString &host)
-{
-    KIO_DATA << host << d->slaveid;
-    send(MSG_NET_REQUEST, data);
-
-    if (waitForAnswer(INF_NETWORK_STATUS, 0, data) != -1) {
-        bool status;
-        QDataStream stream(data);
-        stream >> status;
-        return status;
-    } else {
-        return false;
-    }
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
-void SlaveBase::dropNetwork(const QString &host)
-{
-    KIO_DATA << host << d->slaveid;
-    send(MSG_NET_DROP, data);
-}
-#endif
-
 void SlaveBase::statEntry(const UDSEntry &entry)
 {
     KIO_DATA << entry;
     send(MSG_STAT_ENTRY, data);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
-void SlaveBase::listEntry(const UDSEntry &entry, bool _ready)
-{
-    if (_ready) {
-        // #366795: many slaves don't create an entry for ".", so we keep track if they do
-        // and we provide a fallback in finished() otherwise.
-        if (entry.stringValue(KIO::UDSEntry::UDS_NAME) == QLatin1Char('.')) {
-            d->m_rootEntryListed = true;
-        }
-        listEntries(d->pendingListEntries);
-        d->pendingListEntries.clear();
-    } else {
-        listEntry(entry);
-    }
-}
-#endif
-
 void SlaveBase::listEntry(const UDSEntry &entry)
 {
     // #366795: many slaves don't create an entry for ".", so we keep track if they do
@@ -859,7 +828,12 @@ void SlaveBase::setHost(QString const &, quint16, QString const &, QString const
 {
 }
 
-KIOCORE_EXPORT QString KIO::unsupportedActionErrorString(const QString &protocol, int cmd)
+// TODO: move unsupportedActionErrorString() to workerbase.cpp
+// once SlaveBase is dissolved and folded into WorkerBase
+// forward declaration is already in workerbase.h
+namespace KIO
+{
+KIOCORE_EXPORT QString unsupportedActionErrorString(const QString &protocol, int cmd)
 {
     switch (cmd) {
     case CMD_CONNECT:
@@ -892,16 +866,13 @@ KIOCORE_EXPORT QString KIO::unsupportedActionErrorString(const QString &protocol
         return i18n("Changing the attributes of files is not supported with protocol %1.", protocol);
     case CMD_CHOWN:
         return i18n("Changing the ownership of files is not supported with protocol %1.", protocol);
-    case CMD_SUBURL:
-        return i18n("Using sub-URLs with %1 is not supported.", protocol);
-    case CMD_MULTI_GET:
-        return i18n("Multiple get is not supported with protocol %1.", protocol);
     case CMD_OPEN:
         return i18n("Opening files is not supported with protocol %1.", protocol);
     default:
         return i18n("Protocol %1 does not support action %2.", protocol, cmd);
     } /*end switch*/
 }
+}
 
 void SlaveBase::openConnection()
 {
@@ -990,14 +961,6 @@ void SlaveBase::chown(QUrl const &, const QString &, const QString &)
 {
     error(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(protocolName(), CMD_CHOWN));
 }
-void SlaveBase::setSubUrl(QUrl const &)
-{
-    error(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(protocolName(), CMD_SUBURL));
-}
-void SlaveBase::multiGet(const QByteArray &)
-{
-    error(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(protocolName(), CMD_MULTI_GET));
-}
 
 void SlaveBase::slave_status()
 {
@@ -1010,14 +973,6 @@ void SlaveBase::reparseConfiguration()
     d->remotefile = nullptr;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 24)
-bool SlaveBase::openPasswordDialog(AuthInfo &info, const QString &errorMsg)
-{
-    const int errorCode = openPasswordDialogV2(info, errorMsg);
-    return errorCode == KJob::NoError;
-}
-#endif
-
 int SlaveBase::openPasswordDialogV2(AuthInfo &info, const QString &errorMsg)
 {
     const long windowId = metaData(QStringLiteral("window-id")).toLong();
@@ -1061,32 +1016,26 @@ int SlaveBase::messageBox(const QString &text,
                           const QString &secondaryActionText,
                           const QString &dontAskAgainName)
 {
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
-    if ((type != Information) || (type != SSLMessageBox)) {
-        if (primaryActionText.isNull()) {
-            qCWarning(KIO_CORE) << "Deprecated: messageBox() called with null primaryActionText arg."
-                                << "type:" << type << "text:" << text;
-        }
-        if ((type != WarningContinueCancel) || (type != WarningContinueCancelDetailed)) {
-            if (secondaryActionText.isNull()) {
-                qCWarning(KIO_CORE) << "Deprecated: messageBox() called with null secondaryActionText arg."
-                                    << "type:" << type << "text:" << text;
-            }
-        }
-    }
-    const QString _primaryActionText = primaryActionText.isNull() ? i18n("&Yes") : primaryActionText;
-    const QString _secondaryActionText = secondaryActionText.isNull() ? i18n("&No") : secondaryActionText;
-    // qDebug() << "messageBox " << type << " " << text << " - " << title << _primaryActionText << _secondaryActionText;
-    KIO_DATA << static_cast<qint32>(type) << text << title << _primaryActionText << _secondaryActionText << dontAskAgainName;
-#else
     KIO_DATA << static_cast<qint32>(type) << text << title << primaryActionText << secondaryActionText << dontAskAgainName;
-#endif
     send(INF_MESSAGEBOX, data);
     if (waitForAnswer(CMD_MESSAGEBOXANSWER, 0, data) != -1) {
         QDataStream stream(data);
         int answer;
         stream >> answer;
-        // qDebug() << "got messagebox answer" << answer;
+        return answer;
+    } else {
+        return 0; // communication failure
+    }
+}
+
+int SlaveBase::sslError(const QVariantMap &sslData)
+{
+    KIO_DATA << sslData;
+    send(INF_SSLERROR, data);
+    if (waitForAnswer(CMD_SSLERRORANSWER, 0, data) != -1) {
+        QDataStream stream(data);
+        int answer;
+        stream >> answer;
         return answer;
     } else {
         return 0; // communication failure
@@ -1191,7 +1140,7 @@ void SlaveBase::dispatch(int command, const QByteArray &data)
         closeConnection();
         break;
     }
-    case CMD_SLAVE_STATUS: {
+    case CMD_WORKER_STATUS: {
         d->m_state = d->InsideMethod;
         d->m_finalityCommand = false;
         slave_status();
@@ -1199,32 +1148,6 @@ void SlaveBase::dispatch(int command, const QByteArray &data)
         d->m_state = d->Idle;
         break;
     }
-    case CMD_SLAVE_CONNECT: {
-        d->onHold = false;
-        QString app_socket;
-        QDataStream stream(data);
-        stream >> app_socket;
-        d->appConnection.send(MSG_SLAVE_ACK);
-        disconnectSlave();
-        d->isConnectedToApp = true;
-        connectSlave(app_socket);
-        virtual_hook(AppConnectionMade, nullptr);
-        break;
-    }
-    case CMD_SLAVE_HOLD: { // TODO KF6: remove, unused
-        QUrl url;
-        QDataStream stream(data);
-        stream >> url;
-        d->onHoldUrl = url;
-        d->onHold = true;
-        disconnectSlave();
-        d->isConnectedToApp = false;
-        if (!d->poolSocket.isEmpty()) {
-            // Do not close connection!
-            connectSlave(d->poolSocket);
-        }
-        break;
-    }
     case CMD_REPARSECONFIGURATION: {
         d->m_state = d->InsideMethod;
         d->m_finalityCommand = false;
@@ -1403,25 +1326,10 @@ void SlaveBase::dispatch(int command, const QByteArray &data)
         d->rebuildConfig();
         break;
     }
-    case CMD_SUBURL: {
-        stream >> url;
-        d->m_state = d->InsideMethod;
-        setSubUrl(url);
-        d->verifyErrorFinishedNotCalled("setSubUrl()");
-        d->m_state = d->Idle;
-        break;
-    }
     case CMD_NONE: {
         qCWarning(KIO_CORE) << "Got unexpected CMD_NONE!";
         break;
     }
-    case CMD_MULTI_GET: {
-        d->m_state = d->InsideMethod;
-        multiGet(data);
-        d->verifyState("multiGet()");
-        d->m_state = d->Idle;
-        break;
-    }
     case CMD_FILESYSTEMFREESPACE: {
         stream >> url;
 
@@ -1640,7 +1548,7 @@ PrivilegeOperationStatus SlaveBase::requestPrivilegeOperation(const QString &ope
     if (metaData(QStringLiteral("UnitTesting")) != QLatin1String("true") && d->m_privilegeOperationStatus == OperationAllowed && !d->m_confirmationAsked) {
         // WORKER_MESSAGEBOX_DETAILS_HACK
         // SlaveBase::messageBox() overloads miss a parameter to pass an details argument.
-        // As workaround details are passed instead via metadata before and then cached by the SlaveInterface,
+        // As workaround details are passed instead via metadata before and then cached by the WorkerInterface,
         // to be used in the upcoming messageBox call (needs WarningContinueCancelDetailed type)
         // TODO: add a messageBox() overload taking details and use here,
         // then remove or adapt all code marked with WORKER_MESSAGEBOX_DETAILS
@@ -1659,10 +1567,3 @@ void SlaveBase::addTemporaryAuthorization(const QString &action)
 {
     d->m_tempAuths.insert(action);
 }
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 66)
-PrivilegeOperationStatus SlaveBase::requestPrivilegeOperation()
-{
-    return KIO::OperationNotAllowed;
-}
-#endif
