@@ -109,7 +109,6 @@ public:
      * urlNavigator->saveLocationState(state);
      * \endcode
      *
-     * @since 4.5
      */
     void saveLocationState(const QByteArray &state);
 
@@ -164,7 +163,6 @@ public:
     /**
      * Sets the home URL used by KUrlNavigator::goHome(). If no
      * home URL is set, the default home path of the user is used.
-     * @since 4.5
      */
     // KDE5: Remove the home-property. It is sufficient to invoke
     // KUrlNavigator::setLocationUrl(homeUrl) on application-side.
@@ -194,7 +192,6 @@ public:
      * in the breadcrumb view, if showing the full path is turned off. If
      * showing the full path is turned on, the URL is shown
      * as [/] > [home] > [Pictures] > [2008].
-     * @since 4.2
      */
     void setShowFullPath(bool show);
 
@@ -258,25 +255,6 @@ public:
      */
     KUrlComboBox *editor() const;
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 103)
-    /**
-     * If an application supports only some special protocols, they can be set
-     * with \a protocols .
-     * @deprecated Since 5.103, use setSupportedSchemes(const QStringList &) instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 103, "Use KUrlNavigator::setSupportedSchemes(const QStringList &)")
-    void setCustomProtocols(const QStringList &protocols);
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 103)
-    /**
-     * @return The custom protocols if they are set, QStringList() otherwise.
-     * @deprecated Since 5.103, use supportedSchemes() const instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 103, "Use KUrlNavigator::supportedSchemes() const")
-    QStringList customProtocols() const;
-#endif
-
     /**
      * Set the URL schemes that the navigator should allow navigating to.
      *
@@ -333,73 +311,12 @@ public:
      */
     bool sortHiddenFoldersLast() const;
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * @return     The current URL of the location.
-     * @deprecated Since 4.5, use KUrlNavigator::locationUrl() instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationUrl(int)")
-    const QUrl &url() const;
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * @return The portion of the current URL up to the path part given
-     * by \a index. Assuming that the current URL is /home/peter/Documents/Music,
-     * then the following URLs are returned for an index:
-     * - index <= 0: /home
-     * - index is 1: /home/peter
-     * - index is 2: /home/peter/Documents
-     * - index >= 3: /home/peter/Documents/Music
-     * @deprecated Since 4.5. It should not be necessary for a client of KUrlNavigator to query this information.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Do not use")
-    QUrl url(int index) const;
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * @return URL for the history element with the index \a historyIndex.
-     *         The history index 0 represents the most recent URL.
-     * @since 4.3
-     * @deprecated Since 4.5, use KUrlNavigator::locationUrl(historyIndex) instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationUrl(int)")
-    QUrl historyUrl(int historyIndex) const;
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * @return The saved root URL for the current URL (see KUrlNavigator::saveRootUrl()).
-     * @deprecated Since 4.5, use KUrlNavigator::locationState() instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationState(int)")
-    const QUrl &savedRootUrl() const;
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * @return The saved contents position of the upper left corner
-     *         for the current URL.
-     * @deprecated Since 4.5, use KUrlNavigator::locationState() instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationState(int)")
-    QPoint savedPosition() const;
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /** @deprecated Since 4.5, use setHomeUrl(const QUrl& url) instead. */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::setHomeUrl(const QUrl&)")
-    void setHomeUrl(const QString &homeUrl);
-#endif
-
 public Q_SLOTS:
     /**
      * Sets the location to \a url. The old URL is added to the history.
      * The signals KUrlNavigator::urlAboutToBeChanged(), KUrlNavigator::urlChanged()
      * and KUrlNavigator::historyChanged() are emitted. Use
      * KUrlNavigator::locationUrl() to read the location.
-     * @since 4.5
      */
     void setLocationUrl(const QUrl &url);
 
@@ -415,33 +332,6 @@ public Q_SLOTS:
     void setFocus();
 #endif
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * Sets the location to \a url.
-     * @deprecated Since 4.5, use KUrlNavigator::setLocationUrl(url).
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::setLocationUrl(const QUrl&))")
-    void setUrl(const QUrl &url);
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * Saves the used root URL of the content for the current history element.
-     * @deprecated Since 4.5, use KUrlNavigator::saveLocationState() instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::saveLocationState(const QByteArray &)")
-    void saveRootUrl(const QUrl &url);
-#endif
-
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * Saves the coordinates of the contents for the current history element.
-     * @deprecated Since 4.5, use KUrlNavigator::saveLocationState() instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::saveLocationState(const QByteArray &)")
-    void savePosition(int x, int y);
-#endif
-
 Q_SIGNALS:
     /**
      * Is emitted, if the URL navigator has been activated by
@@ -462,7 +352,6 @@ Q_SIGNALS:
      * The signal KUrlNavigator::urlChanged() will be emitted after the change
      * has been done. Connecting to this signal is useful to save the state
      * of a view with KUrlNavigator::saveLocationState().
-     * @since 4.5
      */
     void urlAboutToBeChanged(const QUrl &newUrl);
 
@@ -482,7 +371,6 @@ Q_SIGNALS:
      * Is emitted if a dropping has been done above the destination
      * \a destination. The receiver must accept the drop event if
      * the dropped data can be handled.
-     * @since 4.2
      */
     void urlsDropped(const QUrl &destination, QDropEvent *event);
 
@@ -495,7 +383,6 @@ Q_SIGNALS:
      * Is emitted if the URL \a url should be opened in a new inactive tab because
      * the user clicked on a breadcrumb with the middle mouse button or
      * left-clicked with the ctrl modifier pressed.
-     * @since 4.5
      */
     void tabRequested(const QUrl &url);
 
