@@ -23,6 +23,10 @@
 #include <KLocalizedString>
 #include <KWindowSystem>
 
+#if HAVE_WAYLAND
+#include <KWaylandExtras>
+#endif
+
 #ifndef Q_OS_ANDROID
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -54,16 +58,17 @@ KProcessRunner::KProcessRunner()
 static KProcessRunner *makeInstance()
 {
 #if defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID)
-    if (SystemdProcessRunner::isAvailable()) {
-        if (qEnvironmentVariableIntValue("KDE_APPLICATIONS_AS_SERVICE")) {
-            return new SystemdProcessRunner();
-        }
-        if (qEnvironmentVariableIntValue("KDE_APPLICATIONS_AS_SCOPE")) {
-            return new ScopedProcessRunner();
-        }
-    }
+    switch (SystemdProcessRunner::modeAvailable()) {
+    case KProcessRunner::SystemdAsService:
+        return new SystemdProcessRunner();
+    case KProcessRunner::SystemdAsScope:
+        return new ScopedProcessRunner();
+    default:
+#else
+    {
 #endif
-    return new ForkingProcessRunner();
+        return new ForkingProcessRunner();
+    }
 }
 
 static void modifyEnv(KProcess &process, QProcessEnvironment mod)
@@ -138,14 +143,13 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
         }
     }
 
-    instance->init(service, serviceEntryPath, service->name(), service->icon(), asn);
+    instance->init(service, serviceEntryPath, service->name(), asn);
     return instance;
 }
 
 KProcessRunner *KProcessRunner::fromCommand(const QString &cmd,
                                             const QString &desktopName,
                                             const QString &execName,
-                                            const QString &iconName,
                                             const QByteArray &asn,
                                             const QString &workingDirectory,
                                             const QProcessEnvironment &environment)
@@ -167,14 +171,13 @@ KProcessRunner *KProcessRunner::fromCommand(const QString &cmd,
 #endif
         instance->m_process->setShellCommand(cmd);
 
-    instance->initFromDesktopName(desktopName, execName, iconName, asn, workingDirectory, environment);
+    instance->initFromDesktopName(desktopName, execName, asn, workingDirectory, environment);
     return instance;
 }
 
 KProcessRunner *KProcessRunner::fromExecutable(const QString &executable,
                                                const QStringList &args,
                                                const QString &desktopName,
-                                               const QString &iconName,
                                                const QByteArray &asn,
                                                const QString &workingDirectory,
                                                const QProcessEnvironment &environment)
@@ -189,13 +192,12 @@ KProcessRunner *KProcessRunner::fromExecutable(const QString &executable,
 
     instance->m_executable = KIO::DesktopExecParser::executablePath(executable);
     instance->m_process->setProgram(executable, args);
-    instance->initFromDesktopName(desktopName, executable, iconName, asn, workingDirectory, environment);
+    instance->initFromDesktopName(desktopName, executable, asn, workingDirectory, environment);
     return instance;
 }
 
 void KProcessRunner::initFromDesktopName(const QString &desktopName,
                                          const QString &execName,
-                                         const QString &iconName,
                                          const QByteArray &asn,
                                          const QString &workingDirectory,
                                          const QProcessEnvironment &environment)
@@ -210,18 +212,14 @@ void KProcessRunner::initFromDesktopName(const QString &desktopName,
             if (m_executable.isEmpty()) {
                 m_executable = KIO::DesktopExecParser::executablePath(service->exec());
             }
-            init(service, service->entryPath(), service->name(), service->icon(), asn);
+            init(service, service->entryPath(), service->name(), asn);
             return;
         }
     }
-    init(KService::Ptr(), QString{}, execName /*user-visible name*/, iconName, asn);
+    init(KService::Ptr(), QString{}, execName /*user-visible name*/, asn);
 }
 
-void KProcessRunner::init(const KService::Ptr &service,
-                          const QString &serviceEntryPath,
-                          const QString &userVisibleName,
-                          const QString &iconName,
-                          const QByteArray &asn)
+void KProcessRunner::init(const KService::Ptr &service, const QString &serviceEntryPath, const QString &userVisibleName, const QByteArray &asn)
 {
     m_serviceEntryPath = serviceEntryPath;
     if (service && !serviceEntryPath.isEmpty() && !KDesktopFile::isAuthorizedDesktopFile(serviceEntryPath)) {
@@ -251,9 +249,7 @@ void KProcessRunner::init(const KService::Ptr &service,
                 data.setName(service->name());
             }
             data.setDescription(i18n("Launching %1", data.name()));
-            if (!iconName.isEmpty()) {
-                data.setIcon(iconName);
-            } else if (service && !service->icon().isEmpty()) {
+            if (service && !service->icon().isEmpty()) {
                 data.setIcon(service->icon());
             }
             if (!wmclass.isEmpty()) {
@@ -270,9 +266,9 @@ void KProcessRunner::init(const KService::Ptr &service,
     }
 #else
     Q_UNUSED(userVisibleName);
-    Q_UNUSED(iconName);
 #endif
 
+#if HAVE_WAYLAND
     if (KWindowSystem::isPlatformWayland()) {
         if (!asn.isEmpty()) {
             m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), QString::fromUtf8(asn));
@@ -286,32 +282,32 @@ void KProcessRunner::init(const KService::Ptr &service,
                     window = qGuiApp->allWindows().constFirst();
                 }
                 if (window) {
-                    const int launchedSerial = KWindowSystem::lastInputSerial(window);
+                    const int launchedSerial = KWaylandExtras::lastInputSerial(window);
                     m_waitingForXdgToken = true;
-                    connect(this, &KProcessRunner::xdgActivationTokenArrived, m_process.get(), [this] {
-                        startProcess();
-                    });
-                    connect(KWindowSystem::self(),
-                            &KWindowSystem::xdgActivationTokenArrived,
-                            m_process.get(),
-                            [this, launchedSerial](int tokenSerial, const QString &token) {
-                                if (tokenSerial == launchedSerial) {
-                                    m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
-                                    Q_EMIT xdgActivationTokenArrived();
-                                    m_waitingForXdgToken = false;
-                                }
-                            });
-                    KWindowSystem::requestXdgActivationToken(window, launchedSerial, maybeAliasedName(QFileInfo(m_serviceEntryPath).completeBaseName()));
+                    connect(
+                        KWaylandExtras::self(),
+                        &KWaylandExtras::xdgActivationTokenArrived,
+                        m_process.get(),
+                        [this, launchedSerial](int tokenSerial, const QString &token) {
+                            if (tokenSerial == launchedSerial) {
+                                m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
+                                m_waitingForXdgToken = false;
+                                startProcess();
+                            }
+                        },
+                        Qt::SingleShotConnection);
+                    KWaylandExtras::requestXdgActivationToken(window, launchedSerial, maybeAliasedName(QFileInfo(m_serviceEntryPath).completeBaseName()));
                 }
             }
         }
     }
+#endif
 
     if (service) {
         m_service = service;
         // Store the desktop name, used by debug output and for the systemd unit name
         m_desktopName = service->menuId();
-        if (m_desktopName.isEmpty() && m_executable == QLatin1String("systemsettings5") && m_service->hasServiceType(QLatin1String("KCModule"))) {
+        if (m_desktopName.isEmpty() && m_executable == QLatin1String("systemsettings")) {
             m_desktopName = QStringLiteral("systemsettings.desktop");
         }
         if (m_desktopName.endsWith(QLatin1String(".desktop"))) { // always true, in theory
@@ -337,7 +333,7 @@ void KProcessRunner::init(const KService::Ptr &service,
 
 void ForkingProcessRunner::startProcess()
 {
-    connect(m_process.get(), qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, &ForkingProcessRunner::slotProcessExited);
+    connect(m_process.get(), &QProcess::finished, this, &ForkingProcessRunner::slotProcessExited);
     connect(m_process.get(), &QProcess::started, this, &ForkingProcessRunner::slotProcessStarted, Qt::QueuedConnection);
     connect(m_process.get(), &QProcess::errorOccurred, this, &ForkingProcessRunner::slotProcessError);
     m_process->start();
@@ -472,12 +468,10 @@ bool KIOGuiPrivate::checkStartupNotify(const KService *service, bool *silent_arg
 {
     bool silent = false;
     QByteArray wmclass;
-    if (service && service->property(QStringLiteral("StartupNotify")).isValid()) {
-        silent = !service->property(QStringLiteral("StartupNotify")).toBool();
-        wmclass = service->property(QStringLiteral("StartupWMClass")).toString().toLatin1();
-    } else if (service && service->property(QStringLiteral("X-KDE-StartupNotify")).isValid()) {
-        silent = !service->property(QStringLiteral("X-KDE-StartupNotify")).toBool();
-        wmclass = service->property(QStringLiteral("X-KDE-WMClass")).toString().toLatin1();
+
+    if (service && service->startupNotify().has_value()) {
+        silent = !service->startupNotify().value();
+        wmclass = service->property<QByteArray>(QStringLiteral("StartupWMClass"));
     } else { // non-compliant app
         if (service) {
             if (service->isApplication()) { // doesn't have .desktop entries needed, start as non-compliant
