@@ -31,15 +31,11 @@
 #include <QStandardPaths>
 #include <QThread>
 
-#include <KStartupInfo>
 #include <config-kioexec.h>
 
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <KStartupInfo>
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 #endif
 
 KIOExec::KIOExec(const QStringList &args, bool tempFiles, const QString &suggestedFileName)
@@ -151,7 +147,7 @@ void KIOExec::slotResult(KJob *job)
             // Tell kioexecd to watch the file for changes.
             const QString dest = copyJob->srcUrl().toString();
             qDebug() << "Telling kioexecd to watch path" << path << "dest" << dest;
-            OrgKdeKIOExecdInterface kioexecd(QStringLiteral("org.kde.kioexecd"), QStringLiteral("/modules/kioexecd"), QDBusConnection::sessionBus());
+            OrgKdeKIOExecdInterface kioexecd(QStringLiteral("org.kde.kioexecd6"), QStringLiteral("/modules/kioexecd"), QDBusConnection::sessionBus());
             kioexecd.watch(path, dest);
             mUseDaemon = !kioexecd.lastError().isValid();
             if (!mUseDaemon) {
@@ -205,21 +201,23 @@ void KIOExec::slotRunApp()
 
     qDebug() << "EXEC" << params.join(QLatin1Char(' '));
 
+#if HAVE_X11
     // propagate the startup identification to the started process
     KStartupInfoId id;
     QByteArray startupId;
-#if HAVE_X11
     if (QX11Info::isPlatformX11()) {
         startupId = QX11Info::nextStartupId();
     }
-#endif
     id.initId(startupId);
     id.setupStartupEnv();
+#endif
 
     QString exe(params.takeFirst());
     const int exit_code = QProcess::execute(exe, params);
 
+#if HAVE_X11
     KStartupInfo::resetStartupEnv();
+#endif
 
     qDebug() << "EXEC done";
 
