@@ -22,7 +22,6 @@
 
 #include <QApplication>
 #include <QDialogButtonBox>
-#include <QPointer>
 #include <QRegularExpression>
 #include <QUrl>
 
@@ -41,10 +40,7 @@ public:
     void savePersistentUserReply(KIO::AskUserActionInterface::MessageDialogType type, KConfigGroup &cg, const QString &dontAskAgainName, int result);
 
     WidgetsAskUserActionHandler *const q;
-    QPointer<QWidget> m_parentWidget = nullptr;
-
-    QWidget *getParentWidget(KJob *job);
-    QWidget *getParentWidget(QWidget *widget);
+    QWidget *m_parentWidget = nullptr;
 };
 
 bool KIO::WidgetsAskUserActionHandlerPrivate::gotPersistentUserReply(KIO::AskUserActionInterface::MessageDialogType type,
@@ -110,36 +106,6 @@ void KIO::WidgetsAskUserActionHandlerPrivate::savePersistentUserReply(KIO::AskUs
     }
 }
 
-QWidget *KIO::WidgetsAskUserActionHandlerPrivate::getParentWidget(KJob *job)
-{
-    // This needs to be in qpointer, otherwise copying process
-    // will crash if done in background and dolphin is closed
-    QPointer<QWidget> parentWidget = nullptr;
-
-    if (job) {
-        parentWidget = KJobWidgets::window(job);
-    }
-
-    return getParentWidget(parentWidget);
-}
-
-QWidget *KIO::WidgetsAskUserActionHandlerPrivate::getParentWidget(QWidget *widget)
-{
-    // This needs to be in qpointer, otherwise copying process
-    // will crash if done in background and dolphin is closed
-    QPointer<QWidget> parentWidget = widget;
-
-    if (!parentWidget) {
-        parentWidget = this->m_parentWidget;
-    }
-
-    if (!parentWidget) {
-        parentWidget = qApp->activeWindow();
-    }
-
-    return parentWidget;
-}
-
 KIO::WidgetsAskUserActionHandler::WidgetsAskUserActionHandler(QObject *parent)
     : KIO::AskUserActionInterface(parent)
     , d(new WidgetsAskUserActionHandlerPrivate(this))
@@ -162,8 +128,22 @@ void KIO::WidgetsAskUserActionHandler::askUserRename(KJob *job,
                                                      const QDateTime &mtimeSrc,
                                                      const QDateTime &mtimeDest)
 {
+    QWidget *parentWidget = nullptr;
+
+    if (job) {
+        parentWidget = KJobWidgets::window(job);
+    }
+
+    if (!parentWidget) {
+        parentWidget = d->m_parentWidget;
+    }
+
+    if (!parentWidget) {
+        parentWidget = qApp->activeWindow();
+    }
+
     QMetaObject::invokeMethod(qGuiApp, [=] {
-        auto *dlg = new KIO::RenameDialog(d->getParentWidget(job), title, src, dest, options, sizeSrc, sizeDest, ctimeSrc, ctimeDest, mtimeSrc, mtimeDest);
+        auto *dlg = new KIO::RenameDialog(parentWidget, title, src, dest, options, sizeSrc, sizeDest, ctimeSrc, ctimeDest, mtimeSrc, mtimeDest);
 
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->setWindowModality(Qt::WindowModal);
@@ -181,8 +161,22 @@ void KIO::WidgetsAskUserActionHandler::askUserRename(KJob *job,
 
 void KIO::WidgetsAskUserActionHandler::askUserSkip(KJob *job, KIO::SkipDialog_Options options, const QString &errorText)
 {
+    QWidget *parentWidget = nullptr;
+
+    if (job) {
+        parentWidget = KJobWidgets::window(job);
+    }
+
+    if (!parentWidget) {
+        parentWidget = d->m_parentWidget;
+    }
+
+    if (!parentWidget) {
+        parentWidget = qApp->activeWindow();
+    }
+
     QMetaObject::invokeMethod(qGuiApp, [=] {
-        auto *dlg = new KIO::SkipDialog(d->getParentWidget(job), options, errorText);
+        auto *dlg = new KIO::SkipDialog(parentWidget, options, errorText);
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->setWindowModality(Qt::WindowModal);
 
@@ -323,7 +317,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, De
         }
 
         KSharedConfigPtr kioConfig = KSharedConfig::openConfig(QStringLiteral("kiorc"), KConfig::NoGlobals);
-        ask = kioConfig->group("Confirmations").readEntry(keyName, defaultValue);
+        ask = kioConfig->group(QStringLiteral("Confirmations")).readEntry(keyName, defaultValue);
     }
 
     if (!ask) {
@@ -352,7 +346,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, De
 
             if (isDelete) {
                 KSharedConfigPtr kioConfig = KSharedConfig::openConfig(QStringLiteral("kiorc"), KConfig::NoGlobals);
-                KConfigGroup cg = kioConfig->group("Confirmations");
+                KConfigGroup cg = kioConfig->group(QStringLiteral("Confirmations"));
                 cg.writeEntry(keyName, !dlg->isDontAskAgainChecked());
                 cg.sync();
             }
@@ -372,13 +366,24 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
                                                              const QString &secondaryActionIconName,
                                                              const QString &dontAskAgainName,
                                                              const QString &details,
-                                                             const KIO::MetaData &metaData,
                                                              QWidget *parent)
 {
-    if (d->gotPersistentUserReply(type, KSharedConfig::openConfig(QStringLiteral("kioslaverc"))->group("Notification Messages"), dontAskAgainName)) {
+    if (d->gotPersistentUserReply(type,
+                                  KSharedConfig::openConfig(QStringLiteral("kioslaverc"))->group(QStringLiteral("Notification Messages")),
+                                  dontAskAgainName)) {
         return;
     }
 
+    QWidget *parentWidget = parent;
+
+    if (!parentWidget) {
+        parentWidget = d->m_parentWidget;
+    }
+
+    if (!parentWidget) {
+        parentWidget = qApp->activeWindow();
+    }
+
     const KGuiItem primaryActionButton(primaryActionText, primaryActionIconName);
     const KGuiItem secondaryActionButton(secondaryActionText, secondaryActionIconName);
 
@@ -407,26 +412,10 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
         dlgType = KMessageDialog::WarningContinueCancel;
         hasCancelButton = true;
         break;
-    case AskUserActionInterface::SSLMessageBox:
-        d->sslMessageBox(text, metaData, d->getParentWidget(parent));
-        return;
     case AskUserActionInterface::Information:
         dlgType = KMessageDialog::Information;
         dontAskAgainText = i18nc("@option:check", "Do not show this message again");
         break;
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 97)
-    case AskUserActionInterface::Sorry:
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 97)
-        QT_WARNING_PUSH
-        QT_WARNING_DISABLE_DEPRECATED
-        dlgType = KMessageDialog::Sorry;
-        QT_WARNING_POP
-        dontAskAgainText = QString{}; // No dontAskAgain checkbox
-        break;
-#else
-#error "Cannot build KIOCore with KIO::AskUserActionInterface::Sorry with KMessageDialog::Sorry disabled"
-#endif
-#endif
     case AskUserActionInterface::Error:
         dlgType = KMessageDialog::Error;
         dontAskAgainText = QString{}; // No dontAskAgain checkbox
@@ -438,7 +427,7 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
 
     QMetaObject::invokeMethod(qGuiApp, [=]() {
         auto cancelButton = hasCancelButton ? KStandardGuiItem::cancel() : KGuiItem();
-        auto *dialog = new KMessageDialog(dlgType, text, d->getParentWidget(parent));
+        auto *dialog = new KMessageDialog(dlgType, text, parentWidget);
 
         dialog->setAttribute(Qt::WA_DeleteOnClose);
         dialog->setCaption(title);
@@ -477,7 +466,7 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
 
             if ((result != KMessageDialog::Cancel) && dialog->isDontAskAgainChecked()) {
                 KSharedConfigPtr reqMsgConfig = KSharedConfig::openConfig(QStringLiteral("kioslaverc"));
-                KConfigGroup cg = reqMsgConfig->group("Notification Messages");
+                KConfigGroup cg = reqMsgConfig->group(QStringLiteral("Notification Messages"));
                 d->savePersistentUserReply(type, cg, dontAskAgainName, result);
             }
         });
@@ -486,11 +475,54 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
     });
 }
 
-void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text, const KIO::MetaData &metaData, QWidget *parent)
+void KIO::WidgetsAskUserActionHandler::setWindow(QWidget *window)
 {
-    QWidget *parentWidget = getParentWidget(parent);
+    d->m_parentWidget = window;
+}
 
-    const QStringList sslList = metaData.value(QStringLiteral("ssl_peer_chain")).split(QLatin1Char('\x01'), Qt::SkipEmptyParts);
+void KIO::WidgetsAskUserActionHandler::askIgnoreSslErrors(const QVariantMap &sslErrorData, QWidget *parent)
+{
+    QWidget *parentWidget = parent;
+
+    if (!parentWidget) {
+        parentWidget = d->m_parentWidget;
+    }
+
+    if (!parentWidget) {
+        parentWidget = qApp->activeWindow();
+    }
+
+    QString message = i18n("The server failed the authenticity check (%1).\n\n", sslErrorData[QLatin1String("hostname")].toString());
+
+    message += sslErrorData[QLatin1String("sslError")].toString();
+
+    auto *dialog = new KMessageDialog(KMessageDialog::WarningTwoActionsCancel, message, parentWidget);
+
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->setCaption(i18n("Server Authentication"));
+    dialog->setIcon(QIcon{});
+    dialog->setButtons(KGuiItem{i18n("&Details"), QStringLiteral("documentinfo")}, KStandardGuiItem::cont(), KStandardGuiItem::cancel());
+
+    connect(dialog, &KMessageDialog::finished, this, [this, parentWidget, sslErrorData](int result) {
+        if (result == KMessageDialog::PrimaryAction) {
+            showSslDetails(sslErrorData, parentWidget);
+        } else if (result == KMessageDialog::SecondaryAction) {
+            // continue();
+            Q_EMIT askIgnoreSslErrorsResult(1);
+        } else if (result == KMessageDialog::Cancel) {
+            // cancel();
+            Q_EMIT askIgnoreSslErrorsResult(0);
+        } else {
+            Q_UNREACHABLE();
+        }
+    });
+
+    dialog->show();
+}
+
+void KIO::WidgetsAskUserActionHandler::showSslDetails(const QVariantMap &sslErrorData, QWidget *parentWidget)
+{
+    const QStringList sslList = sslErrorData[QLatin1String("peerCertChain")].toStringList();
 
     QList<QSslCertificate> certChain;
     bool decodedOk = true;
@@ -505,20 +537,21 @@ void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text,
     QMetaObject::invokeMethod(qGuiApp, [=] {
         if (decodedOk) { // Use KSslInfoDialog
             KSslInfoDialog *ksslDlg = new KSslInfoDialog(parentWidget);
-            ksslDlg->setSslInfo(certChain,
-                                metaData.value(QStringLiteral("ssl_peer_ip")),
-                                text, // The URL
-                                metaData.value(QStringLiteral("ssl_protocol_version")),
-                                metaData.value(QStringLiteral("ssl_cipher")),
-                                metaData.value(QStringLiteral("ssl_cipher_used_bits")).toInt(),
-                                metaData.value(QStringLiteral("ssl_cipher_bits")).toInt(),
-                                KSslInfoDialog::certificateErrorsFromString(metaData.value(QStringLiteral("ssl_cert_errors"))));
+            ksslDlg->setSslInfo(
+                certChain,
+                QString(),
+                sslErrorData[QLatin1String("hostname")].toString(),
+                sslErrorData[QLatin1String("protocol")].toString(),
+                sslErrorData[QLatin1String("cipher")].toString(),
+                sslErrorData[QLatin1String("usedBits")].toInt(),
+                sslErrorData[QLatin1String("bits")].toInt(),
+                KSslInfoDialog::certificateErrorsFromString(sslErrorData[QLatin1String("certificateErrors")].toStringList().join(QLatin1Char('\n'))));
 
             // KSslInfoDialog deletes itself by setting Qt::WA_DeleteOnClose
 
-            QObject::connect(ksslDlg, &QDialog::finished, q, [this]() {
+            QObject::connect(ksslDlg, &QDialog::finished, this, [this, sslErrorData, parentWidget]() {
                 // KSslInfoDialog only has one button, QDialogButtonBox::Close
-                Q_EMIT q->messageBoxResult(KIO::WorkerBase::Cancel);
+                askIgnoreSslErrors(sslErrorData, parentWidget);
             });
 
             ksslDlg->show();
@@ -530,21 +563,14 @@ void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text,
 
         dialog->setAttribute(Qt::WA_DeleteOnClose);
         dialog->setCaption(i18n("SSL"));
-        // KMessageDialog will set a proper icon
-        dialog->setIcon(QIcon{});
         dialog->setButtons(KStandardGuiItem::ok());
 
-        QObject::connect(dialog, &QDialog::finished, q, [this](const int result) {
-            Q_EMIT q->messageBoxResult(result == KMessageDialog::Ok ? KIO::WorkerBase::Ok : KIO::WorkerBase::Cancel);
+        QObject::connect(dialog, &QDialog::finished, this, [this](const int result) {
+            Q_EMIT askIgnoreSslErrorsResult(result == KMessageDialog::Ok ? 1 : 0);
         });
 
         dialog->show();
     });
 }
 
-void KIO::WidgetsAskUserActionHandler::setWindow(QWidget *window)
-{
-    d->m_parentWidget = window;
-}
-
 #include "moc_widgetsaskuseractionhandler.cpp"
